==> terraform-compliance-1.1.14.tar.gz: terraform-compliance-1.1.14/terraform_compliance/common/defaults.py <==
import sys
import os
import colorful
from emoji import emojize


class Defaults(object):

    mounted_ptr = 'terraform-compliance.mounted'
    r_mount_ptr = 'terraform-compliance.mounted_resources'
    r_mount_addr_ptr = 'terraform-compliance.mounted_resources.addresses'
    r_mount_addr_ptr_list = 'terraform-compliance.mounted_resources.addresses_list'

    def __init__(self):
        self.interactive_mode = self.detect_term()
        self.no_failure_tags = ['warning', 'no-failure', 'no-fail', 'info', 'nofailure', 'nofail', 'dontfail']

        if '--no-ansi' in sys.argv or not sys.stdout.isatty():
            self.skip_colour = \
            self.warning_colour = \
            self.failure_colour = \
            self.info_colour = \
            self.yellow = \
            self.red = \
            self.green = \
            self.blue = \
                self.no_coloured_output

            self.info_icon = '*'
            self.warning_icon = '!'
            self.tada = ''
            self.icon = '>'

        else:
            self.skip_colour = colorful.bold_purple
            self.failure_colour = colorful.bold_red
            self.warning_colour = colorful.bold_yellow
            self.info_colour = colorful.bold_blue
            self.yellow = colorful.yellow
            self.red = colorful.red
            self.green = colorful.green
            self.blue = colorful.blue

            self.info_icon = emojize(':bulb:', use_aliases=True)
            self.warning_icon = emojize(':exclamation:', use_aliases=True)
            self.tada = emojize(':tada:', use_aliases=True)
            self.icon = emojize(':triangular_flag_on_post:', use_aliases=True)

    @staticmethod
    def no_coloured_output(param):
        return param

    @staticmethod
    def detect_term():
        return False if colorful.terminal.detect_color_support(env=os.environ) == 0 else True

==> terraform-compliance-1.2.6.tar.gz: terraform-compliance-1.2.6/terraform_compliance/common/defaults.py <==
import sys
import os
import colorful
from emoji import emojize


class Defaults(object):

    mounted_ptr = 'terraform-compliance.mounted'
    r_mount_ptr = 'terraform-compliance.mounted_resources'
    r_mount_addr_ptr = 'terraform-compliance.mounted_resources.addresses'
    r_mount_addr_ptr_list = 'terraform-compliance.mounted_resources.addresses_list'

    def __init__(self):
        self.interactive_mode = self.detect_term()
        self.no_failure_tags = ['warning', 'no-failure', 'no-fail', 'info', 'nofailure', 'nofail', 'dontfail']
        self.case_sensitive_tags = ['case-sensitive', 'case_sensitive', 'casesensitive', 'case-sensitivity']

        if '--no-ansi' in sys.argv or not sys.stdout.isatty():
            self.skip_colour = \
            self.warning_colour = \
            self.failure_colour = \
            self.info_colour = \
            self.yellow = \
            self.red = \
            self.green = \
            self.blue = \
                self.no_coloured_output

            self.info_icon = '*'
            self.warning_icon = '!'
            self.tada = ''
            self.icon = '>'

        else:
            self.skip_colour = colorful.bold_purple
            self.failure_colour = colorful.bold_red
            self.warning_colour = colorful.bold_yellow
            self.info_colour = colorful.bold_blue
            self.yellow = colorful.yellow
            self.red = colorful.red
            self.green = colorful.green
            self.blue = colorful.blue

            self.info_icon = emojize(':bulb:', use_aliases=True)
            self.warning_icon = emojize(':exclamation:', use_aliases=True)
            self.tada = emojize(':tada:', use_aliases=True)
            self.icon = emojize(':triangular_flag_on_post:', use_aliases=True)

        self.types_list = ['resource', 'variable', 'provider', 'data', 'resource that supports tags']

    @staticmethod
    def no_coloured_output(param):
        return param

    @staticmethod
    def detect_term():
        return False if colorful.terminal.detect_color_support(env=os.environ) == 0 else True
